@@ -119,6 +119,8 @@ from sedaro_base_client.model.field_of_view_bg import FieldOfViewBG
 from sedaro_base_client.model.fixed_surface import FixedSurface
 from sedaro_base_client.model.fuel_reservoir import FuelReservoir
 from sedaro_base_client.model.fuel_reservoir_bg import FuelReservoirBG
+from sedaro_base_client.model.fuel_reservoir_create import FuelReservoirCreate
+from sedaro_base_client.model.fuel_reservoir_update import FuelReservoirUpdate
 from sedaro_base_client.model.fully_reg_det_topology import FullyRegDetTopology
 from sedaro_base_client.model.gps_algorithm import GPSAlgorithm
 from sedaro_base_client.model.gps_algorithm_create import GPSAlgorithmCreate
@@ -218,6 +220,7 @@ from sedaro_base_client.model.scenario_block_create_res import ScenarioBlockCrea
 from sedaro_base_client.model.scenario_block_delete_res import ScenarioBlockDeleteRes
 from sedaro_base_client.model.scenario_block_update_res import ScenarioBlockUpdateRes
 from sedaro_base_client.model.scenario_template import ScenarioTemplate
+from sedaro_base_client.model.scenario_template_for_res import ScenarioTemplateForRes
 from sedaro_base_client.model.side_categories import SideCategories
 from sedaro_base_client.model.simulatable_satellite import SimulatableSatellite
 from sedaro_base_client.model.simulation_job import SimulationJob
@@ -242,8 +245,14 @@ from sedaro_base_client.model.space_target_create import SpaceTargetCreate
 from sedaro_base_client.model.space_target_update import SpaceTargetUpdate
 from sedaro_base_client.model.spherical_angles import SphericalAngles
 from sedaro_base_client.model.spherical_fuel_tank import SphericalFuelTank
+from sedaro_base_client.model.spherical_fuel_tank_create import SphericalFuelTankCreate
+from sedaro_base_client.model.spherical_fuel_tank_update import SphericalFuelTankUpdate
 from sedaro_base_client.model.spherocylinder_fuel_tank import SpherocylinderFuelTank
+from sedaro_base_client.model.spherocylinder_fuel_tank_create import SpherocylinderFuelTankCreate
+from sedaro_base_client.model.spherocylinder_fuel_tank_update import SpherocylinderFuelTankUpdate
 from sedaro_base_client.model.static_thrust_control_algorithm import StaticThrustControlAlgorithm
+from sedaro_base_client.model.static_thrust_control_algorithm_create import StaticThrustControlAlgorithmCreate
+from sedaro_base_client.model.static_thrust_control_algorithm_update import StaticThrustControlAlgorithmUpdate
 from sedaro_base_client.model.statuses import Statuses
 from sedaro_base_client.model.subsystem import Subsystem
 from sedaro_base_client.model.subsystem_bg import SubsystemBG
@@ -281,6 +290,8 @@ from sedaro_base_client.model.thermal_interface_material_create import ThermalIn
 from sedaro_base_client.model.thermal_interface_material_update import ThermalInterfaceMaterialUpdate
 from sedaro_base_client.model.thermal_interface_update import ThermalInterfaceUpdate
 from sedaro_base_client.model.thruster import Thruster
+from sedaro_base_client.model.thruster_create import ThrusterCreate
+from sedaro_base_client.model.thruster_update import ThrusterUpdate
 from sedaro_base_client.model.topology import Topology
 from sedaro_base_client.model.topology_param_frd import TopologyParamFRD
 from sedaro_base_client.model.topology_param_qrd import TopologyParamQRD
@@ -303,3 +314,4 @@ from sedaro_base_client.model.vehicle_block_create_res import VehicleBlockCreate
 from sedaro_base_client.model.vehicle_block_delete_res import VehicleBlockDeleteRes
 from sedaro_base_client.model.vehicle_block_update_res import VehicleBlockUpdateRes
 from sedaro_base_client.model.vehicle_template import VehicleTemplate
+from sedaro_base_client.model.vehicle_template_for_res import VehicleTemplateForRes
